Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
Steps []Steps // using UnmarshalYAML so that we don't need a custom type per action
}
func (Action) GetSteps ¶
func (a Action) GetSteps() []builder.ExecutableStep
func (*Action) UnmarshalYAML ¶
UnmarshalYAML takes any yaml in this form ACTION: - cowsay: ... and puts the steps into the Action.Steps field
type Mixin ¶
func (*Mixin) Build ¶
Build will generate the necessary Dockerfile lines for an invocation image using this mixin
func (*Mixin) PrintSchema ¶
func (*Mixin) PrintVersion ¶
func (m *Mixin) PrintVersion()
type Output ¶
type Output struct {
Name string `yaml:"name"`
// See https://porter.sh/mixins/exec/#outputs
// TODO: If your mixin doesn't support these output types, you can remove these and the interface assertions above, and from #/definitions/outputs in schema.json
JsonPath string `yaml:"jsonPath,omitempty"`
FilePath string `yaml:"path,omitempty"`
Regex string `yaml:"regex,omitempty"`
}
func (Output) GetFilePath ¶
func (Output) GetJsonPath ¶
type Step ¶
type Step struct {
Name string `yaml:"name"`
Description string `yaml:"description"`
Arguments []string `yaml:"message,omitempty"`
Flags builder.Flags `yaml:"flags,omitempty"`
Outputs []Output `yaml:"outputs,omitempty"`
}
func (Step) GetArguments ¶
func (Step) GetCommand ¶
func (Step) GetOutputs ¶
type TestMixin ¶
type TestMixin struct {
*Mixin
TestContext *context.TestContext
}
func NewTestMixin ¶
NewTestMixin initializes a mixin test client, with the output buffered, and an in-memory file system.
Click to show internal directories.
Click to hide internal directories.